@@ -291,11 +291,24 @@ function verificationsAfterFieldChange (urlField, multiEdit, theType) {
         $('#salt_' + target.id).remove();
     }
 
-    if (target.value === 'AES_DECRYPT'
-            || target.value === 'AES_ENCRYPT'
-            || target.value === 'MD5') {
+    // Remove possible blocking rules if the user changed functions
+    $('#' + target.id).rules('remove', 'validationFunctionForMd5');
+    $('#' + target.id).rules('remove', 'validationFunctionForAesDesEncrypt');
+
+    if (target.value === 'MD5') {
         $('#' + target.id).rules('add', {
-            validationFunctionForFuns: {
+            validationFunctionForMd5: {
+                param: $thisInput,
+                depends: function () {
+                    return checkForCheckbox(multiEdit);
+                }
+            }
+        });
+    }
+
+    if (target.value === 'DES_ENCRYPT' || target.value === 'AES_ENCRYPT') {
+        $('#' + target.id).rules('add', {
+            validationFunctionForAesDesEncrypt: {
                 param: $thisInput,
                 depends: function () {
                     return checkForCheckbox(multiEdit);
@@ -420,16 +433,27 @@ AJAX.registerOnload('table/change.js', function () {
             return value.match(/^[a-f0-9]*$/i) !== null;
         });
 
-        jQuery.validator.addMethod('validationFunctionForFuns', function (value, element, options) {
-            if (value.substring(0, 3) === 'AES' && options.data('type') !== 'HEX') {
-                return false;
-            }
-
+        jQuery.validator.addMethod('validationFunctionForMd5', function (value, element, options) {
             return !(value.substring(0, 3) === 'MD5' &&
                 typeof options.data('maxlength') !== 'undefined' &&
                 options.data('maxlength') < 32);
         });
 
+        jQuery.validator.addMethod('validationFunctionForAesDesEncrypt', function (value, element, options) {
+            var funType = value.substring(0, 3);
+            if (funType !== 'AES' && funType !== 'DES') {
+                return false;
+            }
+
+            var dataType = options.data('type');
+
+            if (dataType === 'HEX' || dataType === 'CHAR') {
+                return true;
+            }
+
+            return false;
+        });
+
         jQuery.validator.addMethod('validationFunctionForDateTime', function (value, element, options) {
             var dtValue = value;
             var theType = options;
@@ -458,13 +482,14 @@ AJAX.registerOnload('table/change.js', function () {
                     isTime(dtValue.substring(dv + 1));
             }
         });
-        /*
-         * message extending script must be run
-         * after initiation of functions
-         */
-        extendingValidatorMessages();
     }
 
+    /*
+     * message extending script must be run
+     * after initiation of functions
+     */
+    extendingValidatorMessages();
+
     $.datepicker.initialized = false;
 
     $(document).on('click', 'span.open_gis_editor', function (event) {
