@@ -237,8 +237,16 @@ class DatabaseInterface implements DbalInterface
 
                 syslog(
                     LOG_INFO,
-                    'SQL[' . basename($_SERVER['SCRIPT_NAME']) . ']: '
-                    . sprintf('%0.3f', $time) . '(W:' . $warningsCount . ') > ' . $query
+                    sprintf(
+                        'SQL[%s?route=%s]: %0.3f(W:%s,C:%s,L:0x%02X) > %s',
+                        basename($_SERVER['SCRIPT_NAME']),
+                        Routing::getCurrentRoute(),
+                        $time,
+                        $warningsCount,
+                        $cache_affected_rows ? 'y' : 'n',
+                        $link,
+                        $query
+                    )
                 );
                 closelog();
             }
@@ -1632,7 +1640,7 @@ class DatabaseInterface implements DbalInterface
         } else {
             $query = 'SHOW EVENTS FROM ' . Util::backquote($db);
             if (! empty($name)) {
-                $query .= " AND `Name` = '"
+                $query .= " WHERE `Name` = '"
                     . $this->escapeString($name) . "'";
             }
         }
