@@ -1,17 +1,13 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Set of functions used to build XML dumps of tables
- *
- * @package    PhpMyAdmin-Export
- * @subpackage XML
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Export;
 
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Export;
 use PhpMyAdmin\Plugins\ExportPlugin;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup;
@@ -19,18 +15,27 @@ use PhpMyAdmin\Properties\Options\Items\BoolPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\HiddenPropertyItem;
 use PhpMyAdmin\Properties\Plugins\ExportPluginProperties;
 use PhpMyAdmin\Util;
+use const PHP_VERSION;
+use function count;
+use function htmlspecialchars;
+use function is_array;
+use function mb_substr;
+use function rtrim;
+use function str_replace;
+use function stripslashes;
+use function strlen;
 
+// phpcs:disable PSR1.Files.SideEffects
 /* Can't do server export */
 if (! isset($GLOBALS['db']) || strlen($GLOBALS['db']) === 0) {
     $GLOBALS['skip_import'] = true;
+
     return;
 }
+// phpcs:enable
 
 /**
  * Handles the export for the XML class
- *
- * @package    PhpMyAdmin-Export
- * @subpackage XML
  */
 class ExportXml extends ExportPlugin
 {
@@ -39,17 +44,14 @@ class ExportXml extends ExportPlugin
      *
      * @var string
      */
-    private $_table;
+    private $table;
     /**
      * Table names
      *
      * @var array
      */
-    private $_tables;
+    private $tables;
 
-    /**
-     * Constructor
-     */
     public function __construct()
     {
         parent::__construct();
@@ -64,10 +66,12 @@ class ExportXml extends ExportPlugin
     protected function initSpecificVariables()
     {
         global $table, $tables;
-        $this->_setTable($table);
-        if (is_array($tables)) {
-            $this->_setTables($tables);
+        $this->setTable($table);
+        if (! is_array($tables)) {
+            return;
         }
+
+        $this->setTables($tables);
     }
 
     /**
@@ -88,51 +92,51 @@ class ExportXml extends ExportPlugin
         // $exportPluginProperties
         // this will be shown as "Format specific options"
         $exportSpecificOptions = new OptionsPropertyRootGroup(
-            "Format Specific Options"
+            'Format Specific Options'
         );
 
         // general options main group
-        $generalOptions = new OptionsPropertyMainGroup("general_opts");
+        $generalOptions = new OptionsPropertyMainGroup('general_opts');
         // create primary items and add them to the group
-        $leaf = new HiddenPropertyItem("structure_or_data");
+        $leaf = new HiddenPropertyItem('structure_or_data');
         $generalOptions->addProperty($leaf);
         // add the main group to the root group
         $exportSpecificOptions->addProperty($generalOptions);
 
         // export structure main group
         $structure = new OptionsPropertyMainGroup(
-            "structure",
+            'structure',
             __('Object creation options (all are recommended)')
         );
 
         // create primary items and add them to the group
         $leaf = new BoolPropertyItem(
-            "export_events",
+            'export_events',
             __('Events')
         );
         $structure->addProperty($leaf);
         $leaf = new BoolPropertyItem(
-            "export_functions",
+            'export_functions',
             __('Functions')
         );
         $structure->addProperty($leaf);
         $leaf = new BoolPropertyItem(
-            "export_procedures",
+            'export_procedures',
             __('Procedures')
         );
         $structure->addProperty($leaf);
         $leaf = new BoolPropertyItem(
-            "export_tables",
+            'export_tables',
             __('Tables')
         );
         $structure->addProperty($leaf);
         $leaf = new BoolPropertyItem(
-            "export_triggers",
+            'export_triggers',
             __('Triggers')
         );
         $structure->addProperty($leaf);
         $leaf = new BoolPropertyItem(
-            "export_views",
+            'export_views',
             __('Views')
         );
         $structure->addProperty($leaf);
@@ -140,12 +144,12 @@ class ExportXml extends ExportPlugin
 
         // data main group
         $data = new OptionsPropertyMainGroup(
-            "data",
+            'data',
             __('Data dump options')
         );
         // create primary items and add them to the group
         $leaf = new BoolPropertyItem(
-            "export_contents",
+            'export_contents',
             __('Export contents')
         );
         $data->addProperty($leaf);
@@ -161,18 +165,21 @@ class ExportXml extends ExportPlugin
      *
      * @param string $db      Database name
      * @param string $type    Item type to be used in XML output
-     * @param string $dbitype Item type used in DBI qieries
+     * @param string $dbitype Item type used in DBI queries
      *
      * @return string XML with definitions
      */
-    private function _exportRoutines($db, $type, $dbitype)
+    private function exportRoutinesDefinition($db, $type, $dbitype)
     {
+        global $dbi;
+
         // Export routines
-        $routines = $GLOBALS['dbi']->getProceduresOrFunctions(
+        $routines = $dbi->getProceduresOrFunctions(
             $db,
             $dbitype
         );
-        return $this->_exportDefinitions($db, $type, $dbitype, $routines);
+
+        return $this->exportDefinitions($db, $type, $dbitype, $routines);
     }
 
     /**
@@ -180,14 +187,14 @@ class ExportXml extends ExportPlugin
      *
      * @param string $db      Database name
      * @param string $type    Item type to be used in XML output
-     * @param string $dbitype Item type used in DBI qieries
+     * @param string $dbitype Item type used in DBI queries
      * @param array  $names   Names of items to export
      *
      * @return string XML with definitions
      */
-    private function _exportDefinitions($db, $type, $dbitype, array $names)
+    private function exportDefinitions($db, $type, $dbitype, array $names)
     {
-        global $crlf;
+        global $crlf, $dbi;
 
         $head = '';
 
@@ -197,11 +204,11 @@ class ExportXml extends ExportPlugin
                     . htmlspecialchars($name) . '">' . $crlf;
 
                 // Do some formatting
-                $sql = $GLOBALS['dbi']->getDefinition($db, $dbitype, $name);
+                $sql = $dbi->getDefinition($db, $dbitype, $name);
                 $sql = htmlspecialchars(rtrim($sql));
                 $sql = str_replace("\n", "\n                ", $sql);
 
-                $head .= "                " . $sql . $crlf;
+                $head .= '                ' . $sql . $crlf;
                 $head .= '            </pma:' . $type . '>' . $crlf;
             }
         }
@@ -218,16 +225,16 @@ class ExportXml extends ExportPlugin
     public function exportHeader()
     {
         $this->initSpecificVariables();
-        global $crlf, $cfg, $db;
-        $table = $this->_getTable();
-        $tables = $this->_getTables();
+        global $crlf, $cfg, $db, $dbi;
+        $table = $this->getTable();
+        $tables = $this->getTables();
 
         $export_struct = isset($GLOBALS['xml_export_functions'])
             || isset($GLOBALS['xml_export_procedures'])
             || isset($GLOBALS['xml_export_tables'])
             || isset($GLOBALS['xml_export_triggers'])
             || isset($GLOBALS['xml_export_views']);
-        $export_data = isset($GLOBALS['xml_export_contents']) ? true : false;
+        $export_data = isset($GLOBALS['xml_export_contents']);
 
         if ($GLOBALS['output_charset_conversion']) {
             $charset = $GLOBALS['charset'];
@@ -248,7 +255,7 @@ class ExportXml extends ExportPlugin
         $head .= $crlf
             . '- ' . __('Generation Time:') . ' '
             . Util::localisedDate() . $crlf
-            . '- ' . __('Server version:') . ' ' . $GLOBALS['dbi']->getVersionString() . $crlf
+            . '- ' . __('Server version:') . ' ' . $dbi->getVersionString() . $crlf
             . '- ' . __('PHP Version:') . ' ' . PHP_VERSION . $crlf
             . '-->' . $crlf . $crlf;
 
@@ -259,10 +266,10 @@ class ExportXml extends ExportPlugin
             . '>' . $crlf;
 
         if ($export_struct) {
-            $result = $GLOBALS['dbi']->fetchResult(
+            $result = $dbi->fetchResult(
                 'SELECT `DEFAULT_CHARACTER_SET_NAME`, `DEFAULT_COLLATION_NAME`'
                 . ' FROM `information_schema`.`SCHEMATA` WHERE `SCHEMA_NAME`'
-                . ' = \'' . $GLOBALS['dbi']->escapeString($db) . '\' LIMIT 1'
+                . ' = \'' . $dbi->escapeString($db) . '\' LIMIT 1'
             );
             $db_collation = $result[0]['DEFAULT_COLLATION_NAME'];
             $db_charset = $result[0]['DEFAULT_CHARACTER_SET_NAME'];
@@ -285,14 +292,14 @@ class ExportXml extends ExportPlugin
 
             foreach ($tables as $table) {
                 // Export tables and views
-                $result = $GLOBALS['dbi']->fetchResult(
+                $result = $dbi->fetchResult(
                     'SHOW CREATE TABLE ' . Util::backquote($db) . '.'
                     . Util::backquote($table),
                     0
                 );
-                $tbl = $result[$table][1];
+                $tbl = (string) $result[$table][1];
 
-                $is_view = $GLOBALS['dbi']->getTable($db, $table)
+                $is_view = $dbi->getTable($db, $table)
                     ->isView();
 
                 if ($is_view) {
@@ -312,60 +319,63 @@ class ExportXml extends ExportPlugin
                 $head .= '            <pma:' . $type . ' name="' . htmlspecialchars($table) . '">'
                     . $crlf;
 
-                $tbl = "                " . htmlspecialchars($tbl);
+                $tbl = '                ' . htmlspecialchars($tbl);
                 $tbl = str_replace("\n", "\n                ", $tbl);
 
                 $head .= $tbl . ';' . $crlf;
                 $head .= '            </pma:' . $type . '>' . $crlf;
 
-                if (isset($GLOBALS['xml_export_triggers'])
-                    && $GLOBALS['xml_export_triggers']
+                if (! isset($GLOBALS['xml_export_triggers'])
+                    || ! $GLOBALS['xml_export_triggers']
                 ) {
-                    // Export triggers
-                    $triggers = $GLOBALS['dbi']->getTriggers($db, $table);
-                    if ($triggers) {
-                        foreach ($triggers as $trigger) {
-                            $code = $trigger['create'];
-                            $head .= '            <pma:trigger name="'
-                                . htmlspecialchars($trigger['name']) . '">' . $crlf;
-
-                            // Do some formatting
-                            $code = mb_substr(rtrim($code), 0, -3);
-                            $code = "                " . htmlspecialchars($code);
-                            $code = str_replace("\n", "\n                ", $code);
-
-                            $head .= $code . $crlf;
-                            $head .= '            </pma:trigger>' . $crlf;
-                        }
-
-                        unset($trigger);
-                        unset($triggers);
-                    }
+                    continue;
                 }
+
+                // Export triggers
+                $triggers = $dbi->getTriggers($db, $table);
+                if (! $triggers) {
+                    continue;
+                }
+
+                foreach ($triggers as $trigger) {
+                    $code = $trigger['create'];
+                    $head .= '            <pma:trigger name="'
+                        . htmlspecialchars($trigger['name']) . '">' . $crlf;
+
+                    // Do some formatting
+                    $code = mb_substr(rtrim($code), 0, -3);
+                    $code = '                ' . htmlspecialchars($code);
+                    $code = str_replace("\n", "\n                ", $code);
+
+                    $head .= $code . $crlf;
+                    $head .= '            </pma:trigger>' . $crlf;
+                }
+
+                unset($trigger, $triggers);
             }
 
             if (isset($GLOBALS['xml_export_functions'])
                 && $GLOBALS['xml_export_functions']
             ) {
-                $head .= $this->_exportRoutines($db, 'function', 'FUNCTION');
+                $head .= $this->exportRoutinesDefinition($db, 'function', 'FUNCTION');
             }
 
             if (isset($GLOBALS['xml_export_procedures'])
                 && $GLOBALS['xml_export_procedures']
             ) {
-                $head .= $this->_exportRoutines($db, 'procedure', 'PROCEDURE');
+                $head .= $this->exportRoutinesDefinition($db, 'procedure', 'PROCEDURE');
             }
 
             if (isset($GLOBALS['xml_export_events'])
                 && $GLOBALS['xml_export_events']
             ) {
                 // Export events
-                $events = $GLOBALS['dbi']->fetchResult(
-                    "SELECT EVENT_NAME FROM information_schema.EVENTS "
-                    . "WHERE EVENT_SCHEMA='" . $GLOBALS['dbi']->escapeString($db)
+                $events = $dbi->fetchResult(
+                    'SELECT EVENT_NAME FROM information_schema.EVENTS '
+                    . "WHERE EVENT_SCHEMA='" . $dbi->escapeString($db)
                     . "'"
                 );
-                $head .= $this->_exportDefinitions(
+                $head .= $this->exportDefinitions(
                     $db,
                     'event',
                     'EVENT',
@@ -482,8 +492,10 @@ class ExportXml extends ExportPlugin
         $sql_query,
         array $aliases = []
     ) {
+        global $dbi;
+
         // Do not export data for merge tables
-        if ($GLOBALS['dbi']->getTable($db, $table)->isMerge()) {
+        if ($dbi->getTable($db, $table)->isMerge()) {
             return true;
         }
 
@@ -493,16 +505,16 @@ class ExportXml extends ExportPlugin
         if (isset($GLOBALS['xml_export_contents'])
             && $GLOBALS['xml_export_contents']
         ) {
-            $result = $GLOBALS['dbi']->query(
+            $result = $dbi->query(
                 $sql_query,
                 DatabaseInterface::CONNECT_USER,
                 DatabaseInterface::QUERY_UNBUFFERED
             );
 
-            $columns_cnt = $GLOBALS['dbi']->numFields($result);
+            $columns_cnt = $dbi->numFields($result);
             $columns = [];
             for ($i = 0; $i < $columns_cnt; $i++) {
-                $columns[$i] = stripslashes($GLOBALS['dbi']->fieldName($result, $i));
+                $columns[$i] = stripslashes($dbi->fieldName($result, $i));
             }
             unset($i);
 
@@ -512,7 +524,7 @@ class ExportXml extends ExportPlugin
                 return false;
             }
 
-            while ($record = $GLOBALS['dbi']->fetchRow($result)) {
+            while ($record = $dbi->fetchRow($result)) {
                 $buffer = '        <table name="'
                     . htmlspecialchars($table_alias) . '">' . $crlf;
                 for ($i = 0; $i < $columns_cnt; $i++) {
@@ -538,13 +550,12 @@ class ExportXml extends ExportPlugin
                     return false;
                 }
             }
-            $GLOBALS['dbi']->freeResult($result);
+            $dbi->freeResult($result);
         }
 
         return true;
     }
 
-
     /* ~~~~~~~~~~~~~~~~~~~~ Getters and Setters ~~~~~~~~~~~~~~~~~~~~ */
 
     /**
@@ -552,9 +563,9 @@ class ExportXml extends ExportPlugin
      *
      * @return string
      */
-    private function _getTable()
+    private function getTable()
     {
-        return $this->_table;
+        return $this->table;
     }
 
     /**
@@ -564,9 +575,9 @@ class ExportXml extends ExportPlugin
      *
      * @return void
      */
-    private function _setTable($table)
+    private function setTable($table)
     {
-        $this->_table = $table;
+        $this->table = $table;
     }
 
     /**
@@ -574,9 +585,9 @@ class ExportXml extends ExportPlugin
      *
      * @return array
      */
-    private function _getTables()
+    private function getTables()
     {
-        return $this->_tables;
+        return $this->tables;
     }
 
     /**
@@ -586,8 +597,8 @@ class ExportXml extends ExportPlugin
      *
      * @return void
      */
-    private function _setTables(array $tables)
+    private function setTables(array $tables)
     {
-        $this->_tables = $tables;
+        $this->tables = $tables;
     }
 }
