@@ -1,25 +1,39 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * CSV import plugin for phpMyAdmin
  *
  * @todo       add an option for handling NULL values
- * @package    PhpMyAdmin-Import
- * @subpackage CSV
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Plugins\Import;
 
-use PhpMyAdmin\Import;
+use PhpMyAdmin\File;
+use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Message;
 use PhpMyAdmin\Properties\Options\Items\BoolPropertyItem;
+use PhpMyAdmin\Properties\Options\Items\NumberPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\TextPropertyItem;
 use PhpMyAdmin\Util;
+use function array_splice;
+use function basename;
+use function count;
+use function is_array;
+use function mb_strlen;
+use function mb_strpos;
+use function mb_strtolower;
+use function mb_substr;
+use function preg_grep;
+use function preg_replace;
+use function preg_split;
+use function rtrim;
+use function strlen;
+use function strtr;
+use function trim;
 
 /**
  * Handles the import for the CSV format
- *
- * @package    PhpMyAdmin-Import
- * @subpackage CSV
  */
 class ImportCsv extends AbstractImportCsv
 {
@@ -28,13 +42,11 @@ class ImportCsv extends AbstractImportCsv
      *
      * @var bool
      */
-    private $_analyze;
+    private $analyze;
 
-    /**
-     * Constructor
-     */
     public function __construct()
     {
+        parent::__construct();
         $this->setProperties();
     }
 
@@ -46,10 +58,10 @@ class ImportCsv extends AbstractImportCsv
      */
     protected function setProperties()
     {
-        $this->_setAnalyze(false);
+        $this->setAnalyze(false);
 
         if ($GLOBALS['plugin_param'] !== 'table') {
-            $this->_setAnalyze(true);
+            $this->setAnalyze(true);
         }
 
         $generalOptions = parent::setProperties();
@@ -57,8 +69,34 @@ class ImportCsv extends AbstractImportCsv
         $this->properties->setExtension('csv');
 
         if ($GLOBALS['plugin_param'] !== 'table') {
+            $leaf = new TextPropertyItem(
+                'new_tbl_name',
+                __(
+                    'Name of the new table (optional):'
+                )
+            );
+            $generalOptions->addProperty($leaf);
+
+            if ($GLOBALS['plugin_param'] === 'server') {
+                $leaf = new TextPropertyItem(
+                    'new_db_name',
+                    __(
+                        'Name of the new database (optional):'
+                    )
+                );
+                $generalOptions->addProperty($leaf);
+            }
+
+            $leaf = new NumberPropertyItem(
+                'partial_import',
+                __(
+                    'Import these many number of rows (optional):'
+                )
+            );
+            $generalOptions->addProperty($leaf);
+
             $leaf = new BoolPropertyItem(
-                "col_names",
+                'col_names',
                 __(
                     'The first line of the file contains the table column names'
                     . ' <i>(if this is unchecked, the first line will become part'
@@ -67,6 +105,14 @@ class ImportCsv extends AbstractImportCsv
             );
             $generalOptions->addProperty($leaf);
         } else {
+            $leaf = new NumberPropertyItem(
+                'partial_import',
+                __(
+                    'Import these many number of rows (optional):'
+                )
+            );
+            $generalOptions->addProperty($leaf);
+
             $hint = new Message(
                 __(
                     'If the data in each row of the file is not'
@@ -76,14 +122,14 @@ class ImportCsv extends AbstractImportCsv
                 )
             );
             $leaf = new TextPropertyItem(
-                "columns",
-                __('Column names: ') . Util::showHint($hint)
+                'columns',
+                __('Column names:') . ' ' . Generator::showHint($hint)
             );
             $generalOptions->addProperty($leaf);
         }
 
         $leaf = new BoolPropertyItem(
-            "ignore",
+            'ignore',
             __('Do not abort on INSERT error')
         );
         $generalOptions->addProperty($leaf);
@@ -92,137 +138,38 @@ class ImportCsv extends AbstractImportCsv
     /**
      * Handles the whole import logic
      *
-     * @param array &$sql_data 2-element array with sql data
+     * @param array $sql_data 2-element array with sql data
      *
      * @return void
      */
-    public function doImport(array &$sql_data = array())
+    public function doImport(?File $importHandle = null, array &$sql_data = [])
     {
+        global $error, $message, $dbi;
         global $db, $table, $csv_terminated, $csv_enclosed, $csv_escaped,
                $csv_new_line, $csv_columns, $err_url;
         // $csv_replace and $csv_ignore should have been here,
         // but we use directly from $_POST
-        global $error, $timeout_passed, $finished, $message;
+        global $timeout_passed, $finished;
 
-        $replacements = array(
+        $replacements = [
             '\\n' => "\n",
             '\\t' => "\t",
             '\\r' => "\r",
-        );
+        ];
         $csv_terminated = strtr($csv_terminated, $replacements);
         $csv_enclosed = strtr($csv_enclosed, $replacements);
         $csv_escaped = strtr($csv_escaped, $replacements);
         $csv_new_line = strtr($csv_new_line, $replacements);
 
-        $param_error = false;
-        if (strlen($csv_terminated) === 0) {
-            $message = Message::error(
-                __('Invalid parameter for CSV import: %s')
-            );
-            $message->addParam(__('Columns terminated with'));
-            $error = true;
-            $param_error = true;
-            // The default dialog of MS Excel when generating a CSV produces a
-            // semi-colon-separated file with no chance of specifying the
-            // enclosing character. Thus, users who want to import this file
-            // tend to remove the enclosing character on the Import dialog.
-            // I could not find a test case where having no enclosing characters
-            // confuses this script.
-            // But the parser won't work correctly with strings so we allow just
-            // one character.
-        } elseif (mb_strlen($csv_enclosed) > 1) {
-            $message = Message::error(
-                __('Invalid parameter for CSV import: %s')
-            );
-            $message->addParam(__('Columns enclosed with'));
-            $error = true;
-            $param_error = true;
-            // I could not find a test case where having no escaping characters
-            // confuses this script.
-            // But the parser won't work correctly with strings so we allow just
-            // one character.
-        } elseif (mb_strlen($csv_escaped) > 1) {
-            $message = Message::error(
-                __('Invalid parameter for CSV import: %s')
-            );
-            $message->addParam(__('Columns escaped with'));
-            $error = true;
-            $param_error = true;
-        } elseif (mb_strlen($csv_new_line) != 1
-            && $csv_new_line != 'auto'
-        ) {
-            $message = Message::error(
-                __('Invalid parameter for CSV import: %s')
-            );
-            $message->addParam(__('Lines terminated with'));
-            $error = true;
-            $param_error = true;
-        }
+        [$error, $message] = $this->buildErrorsForParams(
+            $csv_terminated,
+            $csv_enclosed,
+            $csv_escaped,
+            $csv_new_line,
+            (string) $err_url
+        );
 
-        // If there is an error in the parameters entered,
-        // indicate that immediately.
-        if ($param_error) {
-            Util::mysqlDie(
-                $message->getMessage(),
-                '',
-                false,
-                $err_url
-            );
-        }
-
-        $buffer = '';
-        $required_fields = 0;
-
-        if (!$this->_getAnalyze()) {
-            $sql_template = 'INSERT';
-            if (isset($_POST['csv_ignore'])) {
-                $sql_template .= ' IGNORE';
-            }
-            $sql_template .= ' INTO ' . Util::backquote($table);
-
-            $tmp_fields = $GLOBALS['dbi']->getColumns($db, $table);
-
-            if (empty($csv_columns)) {
-                $fields = $tmp_fields;
-            } else {
-                $sql_template .= ' (';
-                $fields = array();
-                $tmp = preg_split('/,( ?)/', $csv_columns);
-                foreach ($tmp as $key => $val) {
-                    if (count($fields) > 0) {
-                        $sql_template .= ', ';
-                    }
-                    /* Trim also `, if user already included backquoted fields */
-                    $val = trim($val, " \t\r\n\0\x0B`");
-                    $found = false;
-                    foreach ($tmp_fields as $field) {
-                        if ($field['Field'] == $val) {
-                            $found = true;
-                            break;
-                        }
-                    }
-                    if (!$found) {
-                        $message = Message::error(
-                            __(
-                                'Invalid column (%s) specified! Ensure that columns'
-                                . ' names are spelled correctly, separated by commas'
-                                . ', and not enclosed in quotes.'
-                            )
-                        );
-                        $message->addParam($val);
-                        $error = true;
-                        break;
-                    }
-                    $fields[] = $field;
-                    $sql_template .= Util::backquote($val);
-                }
-                $sql_template .= ') ';
-            }
-
-            $required_fields = count($fields);
-
-            $sql_template .= ' VALUES (';
-        }
+        [$sql_template, $required_fields, $fields] = $this->getSqlTemplateAndRequiredFields($db, $table, $csv_columns);
 
         // Defaults for parser
         $i = 0;
@@ -230,26 +177,42 @@ class ImportCsv extends AbstractImportCsv
         $lastlen = null;
         $line = 1;
         $lasti = -1;
-        $values = array();
+        $values = [];
         $csv_finish = false;
+        $max_lines = 0; // defaults to 0 (get all the lines)
 
-        $tempRow = array();
-        $rows = array();
-        $col_names = array();
-        $tables = array();
+        /**
+         * If we get a negative value, probably someone changed min value
+         * attribute in DOM or there is an integer overflow, whatever be
+         * the case, get all the lines.
+         */
+        if (isset($_REQUEST['csv_partial_import']) && $_REQUEST['csv_partial_import'] > 0) {
+            $max_lines = $_REQUEST['csv_partial_import'];
+        }
+        $max_lines_constraint = $max_lines + 1;
+        // if the first row has to be counted as column names, include one more row in the max lines
+        if (isset($_REQUEST['csv_col_names'])) {
+            $max_lines_constraint++;
+        }
 
+        $tempRow = [];
+        $rows = [];
+        $col_names = [];
+        $tables = [];
+
+        $buffer = '';
         $col_count = 0;
         $max_cols = 0;
         $csv_terminated_len = mb_strlen($csv_terminated);
-        while (!($finished && $i >= $len) && !$error && !$timeout_passed) {
-            $data = Import::getNextChunk();
+        while (! ($finished && $i >= $len) && ! $error && ! $timeout_passed) {
+            $data = $this->import->getNextChunk($importHandle);
             if ($data === false) {
                 // subtract data we didn't handle yet and stop processing
                 $GLOBALS['offset'] -= strlen($buffer);
                 break;
-            } elseif ($data === true) {
-                // Handle rest of buffer
-            } else {
+            }
+
+            if ($data !== true) {
                 // Append new data to buffer
                 $buffer .= $data;
                 unset($data);
@@ -257,12 +220,12 @@ class ImportCsv extends AbstractImportCsv
                 // Force a trailing new line at EOF to prevent parsing problems
                 if ($finished && $buffer) {
                     $finalch = mb_substr($buffer, -1);
-                    if ($csv_new_line == 'auto'
+                    if ($csv_new_line === 'auto'
                         && $finalch != "\r"
                         && $finalch != "\n"
                     ) {
                         $buffer .= "\n";
-                    } elseif ($csv_new_line != 'auto'
+                    } elseif ($csv_new_line !== 'auto'
                         && $finalch != $csv_new_line
                     ) {
                         $buffer .= $csv_new_line;
@@ -271,10 +234,10 @@ class ImportCsv extends AbstractImportCsv
 
                 // Do not parse string when we're not at the end
                 // and don't have new line inside
-                if (($csv_new_line == 'auto'
+                if (($csv_new_line === 'auto'
                     && mb_strpos($buffer, "\r") === false
                     && mb_strpos($buffer, "\n") === false)
-                    || ($csv_new_line != 'auto'
+                    || ($csv_new_line !== 'auto'
                     && mb_strpos($buffer, $csv_new_line) === false)
                 ) {
                     continue;
@@ -309,7 +272,7 @@ class ImportCsv extends AbstractImportCsv
                 $lastlen = $len;
 
                 // This can happen with auto EOL and \r at the end of buffer
-                if (!$csv_finish) {
+                if (! $csv_finish) {
                     // Grab empty field
                     if ($ch == $csv_terminated) {
                         if ($i == $len - 1) {
@@ -356,10 +319,10 @@ class ImportCsv extends AbstractImportCsv
                     while (($need_end
                             && ($ch != $csv_enclosed
                                 || $csv_enclosed == $csv_escaped))
-                        || (!$need_end
-                            && !($ch == $csv_terminated
+                        || (! $need_end
+                            && ! ($ch == $csv_terminated
                                 || $ch == $csv_new_line
-                                || ($csv_new_line == 'auto'
+                                || ($csv_new_line === 'auto'
                                     && ($ch == "\r" || $ch == "\n"))))
                     ) {
                         if ($ch == $csv_escaped) {
@@ -383,7 +346,7 @@ class ImportCsv extends AbstractImportCsv
                             if ($csv_enclosed == $csv_escaped
                                 && ($ch == $csv_terminated
                                 || $ch == $csv_new_line
-                                || ($csv_new_line == 'auto'
+                                || ($csv_new_line === 'auto'
                                 && ($ch == "\r" || $ch == "\n")))
                             ) {
                                 break;
@@ -391,26 +354,28 @@ class ImportCsv extends AbstractImportCsv
                         }
                         $value .= $ch;
                         if ($i == $len - 1) {
-                            if (!$finished) {
+                            if (! $finished) {
                                 $fail = true;
                             }
                             break;
                         }
                         $i++;
                         $ch = mb_substr($buffer, $i, 1);
-                        if ($csv_terminated_len > 1 && $ch == $csv_terminated[0]) {
-                            $ch = $this->readCsvTerminatedString(
-                                $buffer,
-                                $ch,
-                                $i,
-                                $csv_terminated_len
-                            );
-                            $i += $csv_terminated_len - 1;
+                        if ($csv_terminated_len <= 1 || $ch != $csv_terminated[0]) {
+                            continue;
                         }
+
+                        $ch = $this->readCsvTerminatedString(
+                            $buffer,
+                            $ch,
+                            $i,
+                            $csv_terminated_len
+                        );
+                        $i += $csv_terminated_len - 1;
                     }
 
                     // unquoted NULL string
-                    if (false === $need_end && $value === 'NULL') {
+                    if ($need_end === false && $value === 'NULL') {
                         $value = null;
                     }
 
@@ -453,7 +418,7 @@ class ImportCsv extends AbstractImportCsv
                     }
                     // Are we at the end?
                     if ($ch == $csv_new_line
-                        || ($csv_new_line == 'auto' && ($ch == "\r" || $ch == "\n"))
+                        || ($csv_new_line === 'auto' && ($ch == "\r" || $ch == "\n"))
                         || ($finished && $i == $len - 1)
                     ) {
                         $csv_finish = true;
@@ -489,106 +454,115 @@ class ImportCsv extends AbstractImportCsv
                 }
 
                 // End of line
-                if ($csv_finish
-                    || $ch == $csv_new_line
-                    || ($csv_new_line == 'auto' && ($ch == "\r" || $ch == "\n"))
+                if (! $csv_finish
+                    && $ch != $csv_new_line
+                    && ($csv_new_line !== 'auto' || ($ch != "\r" && $ch != "\n"))
                 ) {
-                    if ($csv_new_line == 'auto' && $ch == "\r") { // Handle "\r\n"
-                        if ($i >= ($len - 2) && !$finished) {
-                            break; // We need more data to decide new line
-                        }
-                        if (mb_substr($buffer, $i + 1, 1) == "\n") {
-                            $i++;
-                        }
-                    }
-                    // We didn't parse value till the end of line, so there was
-                    // empty one
-                    if (!$csv_finish) {
-                        $values[] = '';
-                    }
-
-                    if ($this->_getAnalyze()) {
-                        foreach ($values as $val) {
-                            $tempRow[] = $val;
-                            ++$col_count;
-                        }
-
-                        if ($col_count > $max_cols) {
-                            $max_cols = $col_count;
-                        }
-                        $col_count = 0;
-
-                        $rows[] = $tempRow;
-                        $tempRow = array();
-                    } else {
-                        // Do we have correct count of values?
-                        if (count($values) != $required_fields) {
-
-                            // Hack for excel
-                            if ($values[count($values) - 1] == ';') {
-                                unset($values[count($values) - 1]);
-                            } else {
-                                $message = Message::error(
-                                    __(
-                                        'Invalid column count in CSV input'
-                                        . ' on line %d.'
-                                    )
-                                );
-                                $message->addParam($line);
-                                $error = true;
-                                break;
-                            }
-                        }
-
-                        $first = true;
-                        $sql = $sql_template;
-                        foreach ($values as $key => $val) {
-                            if (!$first) {
-                                $sql .= ', ';
-                            }
-                            if ($val === null) {
-                                $sql .= 'NULL';
-                            } else {
-                                $sql .= '\''
-                                    . $GLOBALS['dbi']->escapeString($val)
-                                    . '\'';
-                            }
-
-                            $first = false;
-                        }
-                        $sql .= ')';
-                        if (isset($_POST['csv_replace'])) {
-                            $sql .= " ON DUPLICATE KEY UPDATE ";
-                            foreach ($fields as $field) {
-                                $fieldName = Util::backquote(
-                                    $field['Field']
-                                );
-                                $sql .= $fieldName . " = VALUES(" . $fieldName
-                                    . "), ";
-                            }
-                            $sql = rtrim($sql, ', ');
-                        }
-
-                        /**
-                         * @todo maybe we could add original line to verbose
-                         * SQL in comment
-                         */
-                        Import::runQuery($sql, $sql, $sql_data);
-                    }
-
-                    $line++;
-                    $csv_finish = false;
-                    $values = array();
-                    $buffer = mb_substr($buffer, $i + 1);
-                    $len = mb_strlen($buffer);
-                    $i = 0;
-                    $lasti = -1;
-                    $ch = mb_substr($buffer, 0, 1);
+                    continue;
                 }
-            } // End of parser loop
-        } // End of import loop
 
-        if ($this->_getAnalyze()) {
+                if ($csv_new_line === 'auto' && $ch == "\r") { // Handle "\r\n"
+                    if ($i >= ($len - 2) && ! $finished) {
+                        break; // We need more data to decide new line
+                    }
+                    if (mb_substr($buffer, $i + 1, 1) == "\n") {
+                        $i++;
+                    }
+                }
+                // We didn't parse value till the end of line, so there was
+                // empty one
+                if (! $csv_finish) {
+                    $values[] = '';
+                }
+
+                if ($this->getAnalyze()) {
+                    foreach ($values as $val) {
+                        $tempRow[] = $val;
+                        ++$col_count;
+                    }
+
+                    if ($col_count > $max_cols) {
+                        $max_cols = $col_count;
+                    }
+                    $col_count = 0;
+
+                    $rows[] = $tempRow;
+                    $tempRow = [];
+                } else {
+                    // Do we have correct count of values?
+                    if (count($values) != $required_fields) {
+                        // Hack for excel
+                        if ($values[count($values) - 1] !== ';') {
+                            $message = Message::error(
+                                __(
+                                    'Invalid column count in CSV input'
+                                    . ' on line %d.'
+                                )
+                            );
+                            $message->addParam($line);
+                            $error = true;
+                            break;
+                        }
+
+                        unset($values[count($values) - 1]);
+                    }
+
+                    $first = true;
+                    $sql = $sql_template;
+                    foreach ($values as $key => $val) {
+                        if (! $first) {
+                            $sql .= ', ';
+                        }
+                        if ($val === null) {
+                            $sql .= 'NULL';
+                        } else {
+                            $sql .= '\''
+                                . $dbi->escapeString($val)
+                                . '\'';
+                        }
+
+                        $first = false;
+                    }
+                    $sql .= ')';
+                    if (isset($_POST['csv_replace'])) {
+                        $sql .= ' ON DUPLICATE KEY UPDATE ';
+                        foreach ($fields as $field) {
+                            $fieldName = Util::backquote(
+                                $field['Field']
+                            );
+                            $sql .= $fieldName . ' = VALUES(' . $fieldName
+                                . '), ';
+                        }
+                        $sql = rtrim($sql, ', ');
+                    }
+
+                    /**
+                     * @todo maybe we could add original line to verbose
+                     * SQL in comment
+                     */
+                    $this->import->runQuery($sql, $sql, $sql_data);
+                }
+
+                $line++;
+                $csv_finish = false;
+                $values = [];
+                $buffer = mb_substr($buffer, $i + 1);
+                $len = mb_strlen($buffer);
+                $i = 0;
+                $lasti = -1;
+                $ch = mb_substr($buffer, 0, 1);
+                if ($max_lines > 0 && $line == $max_lines_constraint) {
+                    $finished = 1;
+                    break;
+                }
+            }
+            if ($max_lines > 0 && $line == $max_lines_constraint) {
+                $finished = 1;
+                break;
+            }
+        }
+
+        if ($this->getAnalyze()) {
             /* Fill out all rows */
             $num_rows = count($rows);
             for ($i = 0; $i < $num_rows; ++$i) {
@@ -597,36 +571,18 @@ class ImportCsv extends AbstractImportCsv
                 }
             }
 
-            if (isset($_REQUEST['csv_col_names'])) {
-                $col_names = array_splice($rows, 0, 1);
-                $col_names = $col_names[0];
-                // MySQL column names can't end with a space character.
-                foreach ($col_names as $key => $col_name) {
-                    $col_names[$key] = rtrim($col_name);
-                }
-            }
+            $col_names = $this->getColumnNames($col_names, $max_cols, $rows);
+            $tbl_name = $this->getTableNameFromImport((string) $db);
 
-            if ((isset($col_names) && count($col_names) != $max_cols)
-                || !isset($col_names)
-            ) {
-                // Fill out column names
-                for ($i = 0; $i < $max_cols; ++$i) {
-                    $col_names[] = 'COL ' . ($i + 1);
-                }
-            }
-
-            if (mb_strlen($db)) {
-                $result = $GLOBALS['dbi']->fetchResult('SHOW TABLES');
-                $tbl_name = 'TABLE ' . (count($result) + 1);
-            } else {
-                $tbl_name = 'TBL_NAME';
-            }
-
-            $tables[] = array($tbl_name, $col_names, $rows);
+            $tables[] = [
+                $tbl_name,
+                $col_names,
+                $rows,
+            ];
 
             /* Obtain the best-fit MySQL types for each column */
-            $analyses = array();
-            $analyses[] = Import::analyzeTable($tables[0]);
+            $analyses = [];
+            $analyses[] = $this->import->analyzeTable($tables[0]);
 
             /**
              * string $db_name (no backquotes)
@@ -642,29 +598,238 @@ class ImportCsv extends AbstractImportCsv
              * array $options = an associative array of options
              */
 
-            /* Set database name to the currently selected one, if applicable */
-            list($db_name, $options) = $this->getDbnameAndOptions($db, 'CSV_DB');
+            /* Set database name to the currently selected one, if applicable,
+             * Otherwise, check if user provided the database name in the request,
+             * if not, set the default name
+             */
+            if (isset($_REQUEST['csv_new_db_name'])
+                && strlen($_REQUEST['csv_new_db_name']) > 0
+            ) {
+                $newDb = $_REQUEST['csv_new_db_name'];
+            } else {
+                $result = $dbi->fetchResult('SHOW DATABASES');
+                if (! is_array($result)) {
+                    $result = [];
+                }
+                $newDb = 'CSV_DB ' . (count($result) + 1);
+            }
+            [$db_name, $options] = $this->getDbnameAndOptions($db, $newDb);
 
             /* Non-applicable parameters */
             $create = null;
 
             /* Created and execute necessary SQL statements from data */
-            Import::buildSql($db_name, $tables, $analyses, $create, $options, $sql_data);
+            $this->import->buildSql($db_name, $tables, $analyses, $create, $options, $sql_data);
 
-            unset($tables);
-            unset($analyses);
+            unset($tables, $analyses);
         }
 
         // Commit any possible data in buffers
-        Import::runQuery('', '', $sql_data);
+        $this->import->runQuery('', '', $sql_data);
 
-        if (count($values) != 0 && !$error) {
-            $message = Message::error(
-                __('Invalid format of CSV input on line %d.')
-            );
-            $message->addParam($line);
-            $error = true;
+        if (count($values) == 0 || $error) {
+            return;
         }
+
+        $message = Message::error(
+            __('Invalid format of CSV input on line %d.')
+        );
+        $message->addParam($line);
+        $error = true;
+    }
+
+    private function buildErrorsForParams(
+        string $csvTerminated,
+        string $csvEnclosed,
+        string $csvEscaped,
+        string $csvNewLine,
+        string $errUrl
+    ): array {
+        global $error, $message;
+
+        $param_error = false;
+        if (strlen($csvTerminated) === 0) {
+            $message = Message::error(
+                __('Invalid parameter for CSV import: %s')
+            );
+            $message->addParam(__('Columns terminated with'));
+            $error = true;
+            $param_error = true;
+            // The default dialog of MS Excel when generating a CSV produces a
+            // semi-colon-separated file with no chance of specifying the
+            // enclosing character. Thus, users who want to import this file
+            // tend to remove the enclosing character on the Import dialog.
+            // I could not find a test case where having no enclosing characters
+            // confuses this script.
+            // But the parser won't work correctly with strings so we allow just
+            // one character.
+        } elseif (mb_strlen($csvEnclosed) > 1) {
+            $message = Message::error(
+                __('Invalid parameter for CSV import: %s')
+            );
+            $message->addParam(__('Columns enclosed with'));
+            $error = true;
+            $param_error = true;
+            // I could not find a test case where having no escaping characters
+            // confuses this script.
+            // But the parser won't work correctly with strings so we allow just
+            // one character.
+        } elseif (mb_strlen($csvEscaped) > 1) {
+            $message = Message::error(
+                __('Invalid parameter for CSV import: %s')
+            );
+            $message->addParam(__('Columns escaped with'));
+            $error = true;
+            $param_error = true;
+        } elseif (mb_strlen($csvNewLine) != 1
+            && $csvNewLine !== 'auto'
+        ) {
+            $message = Message::error(
+                __('Invalid parameter for CSV import: %s')
+            );
+            $message->addParam(__('Lines terminated with'));
+            $error = true;
+            $param_error = true;
+        }
+
+        // If there is an error in the parameters entered,
+        // indicate that immediately.
+        if ($param_error) {
+            Generator::mysqlDie(
+                $message->getMessage(),
+                '',
+                false,
+                $errUrl
+            );
+        }
+
+        return [$error, $message];
+    }
+
+    private function getTableNameFromImport(string $databaseName): string
+    {
+        global $import_file_name, $dbi;
+
+        $importFileName = basename($import_file_name, '.csv');
+        $importFileName = mb_strtolower($importFileName);
+        $importFileName = (string) preg_replace('/[^a-zA-Z0-9_]/', '_', $importFileName);
+
+        // get new table name, if user didn't provide one, set the default name
+        if (isset($_REQUEST['csv_new_tbl_name'])
+            && strlen($_REQUEST['csv_new_tbl_name']) > 0
+        ) {
+            return $_REQUEST['csv_new_tbl_name'];
+        }
+        if (mb_strlen($databaseName)) {
+            $result = $dbi->fetchResult('SHOW TABLES');
+
+            // logic to get table name from filename
+            // if no table then use filename as table name
+            if (count($result) === 0) {
+                return $importFileName;
+            }
+            // check to see if {filename} as table exist
+            $nameArray = preg_grep('/' . $importFileName . '/isU', $result);
+            // if no use filename as table name
+            if (count($nameArray) === 0) {
+                return $importFileName;
+            }
+            // check if {filename}_ as table exist
+            $nameArray = preg_grep('/' . $importFileName . '_/isU', $result);
+
+            return $importFileName . '_' . (count($nameArray) + 1);
+        }
+
+        return $importFileName;
+    }
+
+    private function getColumnNames(array $columnNames, int $maxCols, array $rows): array
+    {
+        if (isset($_REQUEST['csv_col_names'])) {
+            $columnNames = array_splice($rows, 0, 1);
+            $columnNames = $columnNames[0];
+            // MySQL column names can't end with a space character.
+            foreach ($columnNames as $key => $col_name) {
+                $columnNames[$key] = rtrim($col_name);
+            }
+        }
+
+        if ((isset($columnNames) && count($columnNames) != $maxCols)
+            || ! isset($columnNames)
+        ) {
+            // Fill out column names
+            for ($i = 0; $i < $maxCols; ++$i) {
+                $columnNames[] = 'COL ' . ($i + 1);
+            }
+        }
+
+        return $columnNames;
+    }
+
+    private function getSqlTemplateAndRequiredFields(
+        ?string $db,
+        ?string $table,
+        ?string $csvColumns
+    ): array {
+        global $dbi, $error, $message;
+
+        $requiredFields = 0;
+        $sqlTemplate = '';
+        $fields = [];
+        if (! $this->getAnalyze() && $db !== null && $table !== null) {
+            $sqlTemplate = 'INSERT';
+            if (isset($_POST['csv_ignore'])) {
+                $sqlTemplate .= ' IGNORE';
+            }
+            $sqlTemplate .= ' INTO ' . Util::backquote($table);
+
+            $tmp_fields = $dbi->getColumns($db, $table);
+
+            if (empty($csvColumns)) {
+                $fields = $tmp_fields;
+            } else {
+                $sqlTemplate .= ' (';
+                $fields = [];
+                $tmp = preg_split('/,( ?)/', $csvColumns);
+                foreach ($tmp as $key => $val) {
+                    if (count($fields) > 0) {
+                        $sqlTemplate .= ', ';
+                    }
+                    /* Trim also `, if user already included backquoted fields */
+                    $val = trim($val, " \t\r\n\0\x0B`");
+                    $found = false;
+                    foreach ($tmp_fields as $field) {
+                        if ($field['Field'] == $val) {
+                            $found = true;
+                            break;
+                        }
+                    }
+                    if (! $found) {
+                        $message = Message::error(
+                            __(
+                                'Invalid column (%s) specified! Ensure that columns'
+                                . ' names are spelled correctly, separated by commas'
+                                . ', and not enclosed in quotes.'
+                            )
+                        );
+                        $message->addParam($val);
+                        $error = true;
+                        break;
+                    }
+                    if (isset($field)) {
+                        $fields[] = $field;
+                    }
+                    $sqlTemplate .= Util::backquote($val);
+                }
+                $sqlTemplate .= ') ';
+            }
+
+            $requiredFields = count($fields);
+
+            $sqlTemplate .= ' VALUES (';
+        }
+
+        return [$sqlTemplate, $requiredFields, $fields];
     }
 
     /**
@@ -692,6 +857,7 @@ class ImportCsv extends AbstractImportCsv
 
         return $ch;
     }
+
     /* ~~~~~~~~~~~~~~~~~~~~ Getters and Setters ~~~~~~~~~~~~~~~~~~~~ */
 
     /**
@@ -699,9 +865,9 @@ class ImportCsv extends AbstractImportCsv
      *
      * @return bool
      */
-    private function _getAnalyze()
+    private function getAnalyze()
     {
-        return $this->_analyze;
+        return $this->analyze;
     }
 
     /**
@@ -711,8 +877,8 @@ class ImportCsv extends AbstractImportCsv
      *
      * @return void
      */
-    private function _setAnalyze($analyze)
+    private function setAnalyze($analyze)
     {
-        $this->_analyze = $analyze;
+        $this->analyze = $analyze;
     }
 }
