@@ -1,11 +1,8 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Image JPEG Upload Input Transformations plugin for phpMyAdmin
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage ImageUpload
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Transformations\Input;
@@ -15,9 +12,6 @@ use PhpMyAdmin\Plugins\Transformations\Abs\ImageUploadTransformationsPlugin;
 /**
  * Handles the image upload input transformation for JPEG.
  * Has two option: width & height of the thumbnail
- *
- * @package    PhpMyAdmin-Transformations
- * @subpackage ImageUpload
  */
 // @codingStandardsIgnoreLine
 class Image_JPEG_Upload extends ImageUploadTransformationsPlugin
@@ -29,7 +23,7 @@ class Image_JPEG_Upload extends ImageUploadTransformationsPlugin
      */
     public static function getMIMEType()
     {
-        return "Image";
+        return 'Image';
     }
 
     /**
@@ -39,6 +33,6 @@ class Image_JPEG_Upload extends ImageUploadTransformationsPlugin
      */
     public static function getMIMESubtype()
     {
-        return "JPEG";
+        return 'JPEG';
     }
 }
