@@ -1,38 +1,33 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Second authentication factor handling
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\TwoFactor;
 
 use PhpMyAdmin\Plugins\TwoFactorPlugin;
 use PhpMyAdmin\Response;
-use PhpMyAdmin\Template;
 use PhpMyAdmin\TwoFactor;
 use Samyoul\U2F\U2FServer\U2FException;
 use Samyoul\U2F\U2FServer\U2FServer;
 use stdClass;
 use Throwable;
-use Twig_Error_Loader;
-use Twig_Error_Runtime;
-use Twig_Error_Syntax;
+use Twig\Error\LoaderError;
+use Twig\Error\RuntimeError;
+use Twig\Error\SyntaxError;
+use function json_decode;
+use function json_encode;
 
 /**
  * Hardware key based two-factor authentication
  *
  * Supports FIDO U2F tokens
- *
- * @package PhpMyAdmin
  */
 class Key extends TwoFactorPlugin
 {
-    /**
-     * @var string
-     */
+    /** @var string */
     public static $id = 'key';
 
     /**
@@ -43,9 +38,11 @@ class Key extends TwoFactorPlugin
     public function __construct(TwoFactor $twofactor)
     {
         parent::__construct($twofactor);
-        if (! isset($this->_twofactor->config['settings']['registrations'])) {
-            $this->_twofactor->config['settings']['registrations'] = [];
+        if (isset($this->twofactor->config['settings']['registrations'])) {
+            return;
         }
+
+        $this->twofactor->config['settings']['registrations'] = [];
     }
 
     /**
@@ -56,7 +53,7 @@ class Key extends TwoFactorPlugin
     public function getRegistrations()
     {
         $result = [];
-        foreach ($this->_twofactor->config['settings']['registrations'] as $index => $data) {
+        foreach ($this->twofactor->config['settings']['registrations'] as $index => $data) {
             $reg = new stdClass();
             $reg->keyHandle = $data['keyHandle'];
             $reg->publicKey = $data['publicKey'];
@@ -65,36 +62,39 @@ class Key extends TwoFactorPlugin
             $reg->index = $index;
             $result[] = $reg;
         }
+
         return $result;
     }
 
     /**
      * Checks authentication, returns true on success
      *
-     * @return boolean
+     * @return bool
      */
     public function check()
     {
-        $this->_provided = false;
-        if (! isset($_POST['u2f_authentication_response']) || ! isset($_SESSION['authenticationRequest'])) {
+        $this->provided = false;
+        if (! isset($_POST['u2f_authentication_response'], $_SESSION['authenticationRequest'])) {
             return false;
         }
-        $this->_provided = true;
+        $this->provided = true;
         try {
             $response = json_decode($_POST['u2f_authentication_response']);
             if ($response === null) {
                 return false;
             }
-            $authentication = U2FServer::authenticate(
+            $auth = U2FServer::authenticate(
                 $_SESSION['authenticationRequest'],
                 $this->getRegistrations(),
                 $response
             );
-            $this->_twofactor->config['settings']['registrations'][$authentication->index]['counter'] = $authentication->counter;
-            $this->_twofactor->save();
+            $this->twofactor->config['settings']['registrations'][$auth->index]['counter'] = $auth->counter;
+            $this->twofactor->save();
+
             return true;
         } catch (U2FException $e) {
-            $this->_message = $e->getMessage();
+            $this->message = $e->getMessage();
+
             return false;
         }
     }
@@ -125,6 +125,7 @@ class Key extends TwoFactorPlugin
         );
         $_SESSION['authenticationRequest'] = $request;
         $this->loadScripts();
+
         return $this->template->render('login/twofactor/key', [
             'request' => json_encode($request),
             'is_https' => $GLOBALS['PMA_Config']->isHttps(),
@@ -135,11 +136,12 @@ class Key extends TwoFactorPlugin
      * Renders user interface to configure two-factor authentication
      *
      * @return string HTML code
+     *
      * @throws U2FException
      * @throws Throwable
-     * @throws Twig_Error_Loader
-     * @throws Twig_Error_Runtime
-     * @throws Twig_Error_Syntax
+     * @throws LoaderError
+     * @throws RuntimeError
+     * @throws SyntaxError
      */
     public function setup()
     {
@@ -150,6 +152,7 @@ class Key extends TwoFactorPlugin
         $_SESSION['registrationRequest'] = $registrationData['request'];
 
         $this->loadScripts();
+
         return $this->template->render('login/twofactor/key_configure', [
             'request' => json_encode($registrationData['request']),
             'signatures' => json_encode($registrationData['signatures']),
@@ -160,15 +163,15 @@ class Key extends TwoFactorPlugin
     /**
      * Performs backend configuration
      *
-     * @return boolean
+     * @return bool
      */
     public function configure()
     {
-        $this->_provided = false;
-        if (! isset($_POST['u2f_registration_response']) || ! isset($_SESSION['registrationRequest'])) {
+        $this->provided = false;
+        if (! isset($_POST['u2f_registration_response'], $_SESSION['registrationRequest'])) {
             return false;
         }
-        $this->_provided = true;
+        $this->provided = true;
         try {
             $response = json_decode($_POST['u2f_registration_response']);
             if ($response === null) {
@@ -178,15 +181,17 @@ class Key extends TwoFactorPlugin
                 $_SESSION['registrationRequest'],
                 $response
             );
-            $this->_twofactor->config['settings']['registrations'][] = [
+            $this->twofactor->config['settings']['registrations'][] = [
                 'keyHandle' => $registration->getKeyHandle(),
                 'publicKey' => $registration->getPublicKey(),
                 'certificate' => $registration->getCertificate(),
                 'counter' => $registration->getCounter(),
             ];
+
             return true;
         } catch (U2FException $e) {
-            $this->_message = $e->getMessage();
+            $this->message = $e->getMessage();
+
             return false;
         }
     }
