@@ -1,10 +1,5 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * hold PhpMyAdmin\Template class
- *
- * @package PhpMyAdmin
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
@@ -15,8 +10,6 @@ use PhpMyAdmin\Twig\MessageExtension;
 use PhpMyAdmin\Twig\PluginsExtension;
 use PhpMyAdmin\Twig\RelationExtension;
 use PhpMyAdmin\Twig\SanitizeExtension;
-use PhpMyAdmin\Twig\ServerPrivilegesExtension;
-use PhpMyAdmin\Twig\StorageEngineExtension;
 use PhpMyAdmin\Twig\TableExtension;
 use PhpMyAdmin\Twig\TrackerExtension;
 use PhpMyAdmin\Twig\TransformationsExtension;
@@ -28,66 +21,67 @@ use Twig\Environment;
 use Twig\Error\LoaderError;
 use Twig\Error\RuntimeError;
 use Twig\Error\SyntaxError;
+use Twig\Extension\DebugExtension;
 use Twig\Loader\FilesystemLoader;
-use Twig_Error_Loader;
-use Twig_Error_Runtime;
-use Twig_Error_Syntax;
-use Twig_TemplateWrapper;
+use Twig\TemplateWrapper;
+use const DIRECTORY_SEPARATOR;
+use const E_USER_WARNING;
+use function sprintf;
+use function trigger_error;
+use function is_array;
 
 /**
- * Class Template
- *
  * Handle front end templating
- *
- * @package PhpMyAdmin
  */
 class Template
 {
     /**
      * Twig environment
+     *
      * @var Environment
      */
     protected static $twig;
 
-    /**
-     * @var string
-     */
-    public const BASE_PATH = 'templates/';
+    public const BASE_PATH = ROOT_PATH . DIRECTORY_SEPARATOR . 'templates' . DIRECTORY_SEPARATOR;
 
-    /**
-     * Template constructor
-     */
     public function __construct()
     {
-        /** @var Config $config */
+        global $cfg;
+
+        /** @var Config|null $config */
         $config = $GLOBALS['PMA_Config'];
-        if (static::$twig === null) {
-            $loader = new FilesystemLoader(self::BASE_PATH);
-            $cache_dir = $config !== null ? $config->getTempDir('twig') : null;
-            /* Twig expects false when cache is not configured */
-            if ($cache_dir === null) {
-                $cache_dir = false;
-            }
-            $twig = new Environment($loader, [
-                'auto_reload' => true,
-                'cache' => $cache_dir,
-                'debug' => false,
-            ]);
-            $twig->addExtension(new CoreExtension());
-            $twig->addExtension(new I18nExtension());
-            $twig->addExtension(new MessageExtension());
-            $twig->addExtension(new PluginsExtension());
-            $twig->addExtension(new RelationExtension());
-            $twig->addExtension(new SanitizeExtension());
-            $twig->addExtension(new ServerPrivilegesExtension());
-            $twig->addExtension(new StorageEngineExtension());
-            $twig->addExtension(new TableExtension());
-            $twig->addExtension(new TrackerExtension());
-            $twig->addExtension(new TransformationsExtension());
-            $twig->addExtension(new UrlExtension());
-            $twig->addExtension(new UtilExtension());
-            static::$twig = $twig;
+        if (static::$twig !== null) {
+            return;
         }
+
+        $loader = new FilesystemLoader(self::BASE_PATH);
+        $cache_dir = $config !== null ? $config->getTempDir('twig') : null;
+        /* Twig expects false when cache is not configured */
+        if ($cache_dir === null) {
+            $cache_dir = false;
+        }
+        $twig = new Environment($loader, [
+            'auto_reload' => true,
+            'cache' => $cache_dir,
+        ]);
+
+        // It was reported that the config could not be loaded correctly
+        if (is_array($cfg) && $cfg['environment'] === 'development') {
+            $twig->enableDebug();
+            $twig->addExtension(new DebugExtension());
+        }
+        $twig->addExtension(new CoreExtension());
+        $twig->addExtension(new I18nExtension());
+        $twig->addExtension(new MessageExtension());
+        $twig->addExtension(new PluginsExtension());
+        $twig->addExtension(new RelationExtension());
+        $twig->addExtension(new SanitizeExtension());
+        $twig->addExtension(new TableExtension());
+        $twig->addExtension(new TrackerExtension());
+        $twig->addExtension(new TransformationsExtension());
+        $twig->addExtension(new UrlExtension());
+        $twig->addExtension(new UtilExtension());
+        static::$twig = $twig;
     }
 
     /**
@@ -95,12 +89,11 @@ class Template
      *
      * @param string $templateName Template path name
      *
-     * @return Twig_TemplateWrapper
      * @throws LoaderError
      * @throws RuntimeError
      * @throws SyntaxError
      */
-    public function load(string $templateName): Twig_TemplateWrapper
+    private function load(string $templateName): TemplateWrapper
     {
         try {
             $template = static::$twig->load($templateName . '.twig');
@@ -129,11 +122,10 @@ class Template
      * @param string $template Template path name
      * @param array  $data     Associative array of template variables
      *
-     * @return string
      * @throws Throwable
-     * @throws Twig_Error_Loader
-     * @throws Twig_Error_Runtime
-     * @throws Twig_Error_Syntax
+     * @throws LoaderError
+     * @throws RuntimeError
+     * @throws SyntaxError
      */
     public function render(string $template, array $data = []): string
     {
