@@ -1,28 +1,54 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Hold the PhpMyAdmin\Utils\HttpRequest class
- *
- * @package PhpMyAdmin
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Utils;
 
+use const CURL_IPRESOLVE_V4;
+use const CURLINFO_HTTP_CODE;
+use const CURLINFO_SSL_VERIFYRESULT;
+use const CURLOPT_CAINFO;
+use const CURLOPT_CAPATH;
+use const CURLOPT_CONNECTTIMEOUT;
+use const CURLOPT_CUSTOMREQUEST;
+use const CURLOPT_FOLLOWLOCATION;
+use const CURLOPT_HTTPHEADER;
+use const CURLOPT_IPRESOLVE;
+use const CURLOPT_POSTFIELDS;
+use const CURLOPT_PROXY;
+use const CURLOPT_PROXYUSERPWD;
+use const CURLOPT_RETURNTRANSFER;
+use const CURLOPT_SSL_VERIFYHOST;
+use const CURLOPT_SSL_VERIFYPEER;
+use const CURLOPT_TIMEOUT;
+use const CURLOPT_USERAGENT;
+use function base64_encode;
+use function curl_exec;
+use function curl_getinfo;
+use function curl_init;
+use function curl_setopt;
+use function file_get_contents;
+use function function_exists;
+use function ini_get;
+use function intval;
+use function preg_match;
+use function stream_context_create;
+use function strlen;
+
 /**
  * Handles HTTP requests
- *
- * @package PhpMyAdmin
  */
 class HttpRequest
 {
+    /** @var string */
     private $proxyUrl;
+
+    /** @var string */
     private $proxyUser;
+
+    /** @var string */
     private $proxyPass;
 
-    /**
-     * Constructor
-     */
     public function __construct()
     {
         global $cfg;
@@ -55,6 +81,7 @@ class HttpRequest
                     . $auth . "\r\n";
             }
         }
+
         return $context;
     }
 
@@ -65,7 +92,7 @@ class HttpRequest
      * @param int   $httpStatus       HTTP response status code
      * @param bool  $returnOnlyStatus If set to true, the method would only return response status
      *
-     * @return string|null|bool
+     * @return string|bool|null
      */
     private function response(
         $response,
@@ -81,6 +108,7 @@ class HttpRequest
         if ($returnOnlyStatus) {
             return true;
         }
+
         return $response;
     }
 
@@ -94,7 +122,7 @@ class HttpRequest
      * @param string $header           Header to be set for the HTTP request
      * @param int    $ssl              SSL mode to use
      *
-     * @return string|null|bool
+     * @return string|bool|null
      */
     private function curl(
         $url,
@@ -121,14 +149,14 @@ class HttpRequest
         }
         $curlStatus &= curl_setopt($curlHandle, CURLOPT_USERAGENT, 'phpMyAdmin');
 
-        if ($method != "GET") {
+        if ($method !== 'GET') {
             $curlStatus &= curl_setopt($curlHandle, CURLOPT_CUSTOMREQUEST, $method);
         }
         if ($header) {
             $curlStatus &= curl_setopt($curlHandle, CURLOPT_HTTPHEADER, [$header]);
         }
 
-        if ($method == "POST") {
+        if ($method === 'POST') {
             $curlStatus &= curl_setopt($curlHandle, CURLOPT_POSTFIELDS, $content);
         }
 
@@ -175,13 +203,17 @@ class HttpRequest
             if (curl_getinfo($curlHandle, CURLINFO_SSL_VERIFYRESULT) != 0) {
                 if ($ssl == 0) {
                     return $this->curl($url, $method, $returnOnlyStatus, $content, $header, CURLOPT_CAINFO);
-                } elseif ($ssl == CURLOPT_CAINFO) {
+                }
+
+                if ($ssl == CURLOPT_CAINFO) {
                     return $this->curl($url, $method, $returnOnlyStatus, $content, $header, CURLOPT_CAPATH);
                 }
             }
+
             return null;
         }
         $httpStatus = curl_getinfo($curlHandle, CURLINFO_HTTP_CODE);
+
         return $this->response($response, $httpStatus, $returnOnlyStatus);
     }
 
@@ -194,7 +226,7 @@ class HttpRequest
      * @param mixed  $content          Content to be sent with HTTP request
      * @param string $header           Header to be set for the HTTP request
      *
-     * @return string|null|bool
+     * @return string|bool|null
      */
     private function fopen(
         $url,
@@ -209,13 +241,13 @@ class HttpRequest
                 'request_fulluri' => true,
                 'timeout' => 10,
                 'user_agent' => 'phpMyAdmin',
-                'header' => "Accept: */*",
+                'header' => 'Accept: */*',
             ],
         ];
         if ($header) {
             $context['http']['header'] .= "\n" . $header;
         }
-        if ($method == "POST") {
+        if ($method === 'POST') {
             $context['http']['content'] = $content;
         }
         $context = $this->handleContext($context);
@@ -224,12 +256,15 @@ class HttpRequest
             false,
             stream_context_create($context)
         );
-        if (isset($http_response_header)) {
-            preg_match("#HTTP/[0-9\.]+\s+([0-9]+)#", $http_response_header[0], $out);
-            $httpStatus = intval($out[1]);
-            return $this->response($response, $httpStatus, $returnOnlyStatus);
+
+        if (! isset($http_response_header)) {
+            return null;
         }
-        return null;
+
+        preg_match('#HTTP/[0-9\.]+\s+([0-9]+)#', $http_response_header[0], $out);
+        $httpStatus = intval($out[1]);
+
+        return $this->response($response, $httpStatus, $returnOnlyStatus);
     }
 
     /**
@@ -241,7 +276,7 @@ class HttpRequest
      * @param mixed  $content          Content to be sent with HTTP request
      * @param string $header           Header to be set for the HTTP request
      *
-     * @return string|null|bool
+     * @return string|bool|null
      */
     public function create(
         $url,
@@ -252,9 +287,12 @@ class HttpRequest
     ) {
         if (function_exists('curl_init')) {
             return $this->curl($url, $method, $returnOnlyStatus, $content, $header);
-        } elseif (ini_get('allow_url_fopen')) {
+        }
+
+        if (ini_get('allow_url_fopen')) {
             return $this->fopen($url, $method, $returnOnlyStatus, $content, $header);
         }
+
         return null;
     }
 }
