@@ -46,9 +46,6 @@ use PhpMyAdmin\Session;
 use PhpMyAdmin\SqlParser\Lexer;
 use PhpMyAdmin\ThemeManager;
 use PhpMyAdmin\Tracker;
-use Symfony\Component\Config\FileLocator;
-use Symfony\Component\DependencyInjection\ContainerBuilder;
-use Symfony\Component\DependencyInjection\Loader\PhpFileLoader;
 
 global $containerBuilder, $error_handler, $PMA_Config, $server, $dbi;
 global $lang, $cfg, $isConfigLoading, $auth_plugin, $route, $PMA_Theme;
@@ -97,6 +94,19 @@ if (! @is_readable(AUTOLOAD_FILE)) {
 }
 require_once AUTOLOAD_FILE;
 
+/**
+ * (TCPDF workaround)
+ * Avoid referring to nonexistent files (causes warnings when open_basedir is used)
+ * This is defined to avoid the tcpdf code to search for a directory outside of open_basedir
+ * See: https://github.com/phpmyadmin/phpmyadmin/issues/16709
+ * This value if not used but is usefull, no header logic is used for PDF exports
+ */
+if (! defined('K_PATH_IMAGES')) {
+    // phpcs:disable PSR1.Files.SideEffects
+    define('K_PATH_IMAGES', ROOT_PATH);
+    // phpcs:enable
+}
+
 $route = Routing::getCurrentRoute();
 
 if ($route === '/import-status') {
@@ -105,9 +115,7 @@ if ($route === '/import-status') {
     // phpcs:enable
 }
 
-$containerBuilder = new ContainerBuilder();
-$loader = new PhpFileLoader($containerBuilder, new FileLocator(__DIR__));
-$loader->load('services_loader.php');
+$containerBuilder = Core::getContainerBuilder();
 
 /**
  * Load gettext functions.
